#
# spec file for package qtox
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           qtox
Version:        1.16.3
Release:        bp153.1.27
Summary:        Qt based Tox client
License:        GPL-3.0-only
Group:          Productivity/Networking/Instant Messenger
Url:            https://qtox.github.io/
Source0:        https://github.com/qTox/qTox/releases/download/v%{version}/v%{version}.tar.gz
Source1:        https://github.com/qTox/qTox/releases/download/v%{version}/v%{version}.tar.gz.asc
Source2:        qtox.keyring
# PATCH-FEATURE-UPSTREAM
Patch:          5041.patch
BuildRequires:  c-toxcore-devel
BuildRequires:  cmake
BuildRequires:  glib2-devel
BuildRequires:  hicolor-icon-theme
BuildRequires:  libqt5-linguist-devel
BuildRequires:  libqt5-qtbase-devel
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(Qt5Svg)
BuildRequires:  pkgconfig(gdk-pixbuf-2.0)
BuildRequires:  pkgconfig(gtk+-2.0)
BuildRequires:  pkgconfig(libavdevice)
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(libavutil)
BuildRequires:  pkgconfig(libexif)
BuildRequires:  pkgconfig(libqrencode)
BuildRequires:  pkgconfig(libsodium)
BuildRequires:  pkgconfig(libswscale)
BuildRequires:  pkgconfig(openal)
BuildRequires:  pkgconfig(opus)
BuildRequires:  pkgconfig(sqlcipher)
BuildRequires:  pkgconfig(vpx)
BuildRequires:  pkgconfig(xscrnsaver)

%description
qTox is a chat, voice, video, and file transfer IM client using the
encrypted peer-to-peer Tox protocol.

%prep
%setup -q -c -n qTox-%{version}

%patch -p1

# W: file-contains-date-and-time
BUILD_TIME=$(LC_ALL=C date -ur %{_sourcedir}/%{name}.changes +'%{H}:%{M}')
BUILD_DATE=$(LC_ALL=C date -ur %{_sourcedir}/%{name}.changes +'%{b} %{d} %{Y}')
sed -i "s/__TIME__/\"$BUILD_TIME\"/" $(grep -rl '__TIME__')
sed -i "s/__DATE__/\"$BUILD_DATE\"/" $(grep -rl '__DATE__')

%build
CFLAGS="%{optflags} -Wno-error=parentheses"
mkdir build
pushd build
cmake -DCMAKE_C_FLAGS="$CFLAGS" -DCMAKE_INSTALL_PREFIX=%{_prefix} ..
make %{?_smp_mflags} PREFIX=%{_prefix}
popd

%install
make install -C build PREFIX=%{_prefix} DESTDIR=%buildroot
# remove non-standard dimensions
rm -rf %{buildroot}%{_datadir}/icons/hicolor/14x14
# decompress svgz to svg
cd %{buildroot}%{_datadir}/icons/hicolor/scalable/apps/
gzip -d < %{name}.svgz > %{name}.svg
rm %{name}.svgz
# fix desktop-file-name
mv %{buildroot}%{_datadir}/applications/io.github.qtox.qTox.desktop %{buildroot}%{_datadir}/applications/%{name}.desktop

%files
%license LICENSE
%doc README.md CHANGELOG.md
%{_bindir}/%{name}
%{_datadir}/metainfo
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}.png
%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg

%changelog
* Sat Sep  1 2018 Andrey Karepin <egdfree@opensuse.org>
- add qtox.keyring file
- change source download URL
* Sun Jul 29 2018 ecsos@opensuse.org
- update to 1.16.3
  This point release fixes flatpak build. No feature changes.
- changes from 1.16.2
  This point release fixes dialog spam from receiving invalid
  filenames and logs spam. No feature changes.
  * Bug Fixes
  * *logging:**
  - only log toxcore messages above TRACE level
  * *ui:**
  - don't emit filename change windows for every chat
- changes from 1.16.1
  This point release fixes our deployment of Flapak and AppImage on
  Github. No feature changes.
  * Features
  * *deploy:**
  - upload Flatpak bundle to Github releases
  * Bug Fixes
  * *deploy:**
  - fix file path in AppImage deployment
- changes from 1.16.0
  The most notable additions in this release are a new fullscreen
  mode for video calls, a new call end sound and support for more
  camera resolutions. To distribute qTox in a more user friendly
  manner we now publish Flatpak and AppImage packages.
  * Bug Fixes
  - remove full screen btn from audio group chat
  - local toxcore install with bootstrap.sh
  - simple_make.sh script
  - Fix PR #5182. Eliminating the 'new' operator at
    ToxOptionsWrapper
  - Fix usage of unitialized functions
  - two crashes, uncovered by the persistent groupchat patch
  - delete double initialization callDuration
  * *Core:**
  - fix use after free of proxyAddrData
  * *appimage:**
  - build sqlcipher form source
  * *audio:**
  - fix error introduced in 67f2605971cf43093c72f811e4df90ab70544dd6
  - connect the correct audio callbacks
  - close the audio device after playing a sound
  * *build:**
  - Elimination the build warnings (Wunused-variable, Wreorder)
  - correct install script nsis for win64
  - make qTox compile with ffmpeg 4.0 and newer
  * *chatform:**
  - name in window title and close detached chats
  - check for empty path when exporting profile
  * *core:**
  - Clean illegal chars from filenames
  * *docs:**
  - update toxcore build instructions
  * *file:**
  - don't clean the filenames of avatar transfer
  * *history:**
  - don't save both action prefix and displayed name
  * *leak:**
  - Fix few memory leaks
  * *login:**
  - start login screen on profile select by -p option
  * *settings:**
  - automatically disable UDP when a proxy is set
  - prevent segfault on wrong proxy settings
  * *simple_make:**
  - correct variable initialization
  * *theme:**
  - clear stylesheet cache on theme colour change
  * *ui:**
  - increase number of low res camera options
  * *video:**
  - unsubscribe the video device correctly
  * *wayland:**
  - Fix desktop file name in Qt properties
  * Features
  - Add ability to remove dialog from content dialog with middle
    click
  - Add ability to quit group with middle click
  - Add middle mouse clicked signal for GenericChatroom
  * *appimage:**
  - build appimage on TravisCI
  * *call:**
  - add call end sound
  * *chat:**
  - add UI option to mute group peers
  - full screen video chat
  * *core:**
  - put c-toxcore log messages in the qTox log
  * *history:**
  - load set number of messages from history
* Thu Jun 28 2018 egdfree@opensuse.org
- add 5041.patch to fix build in factory
  see https://github.com/qTox/qTox/issues/5041#issuecomment-377771790
* Mon Jun 18 2018 sleep_walker@opensuse.org
- disable Werror for parenthesis (breaks the build because of gtk2)
* Sun Jun 17 2018 ecsos@opensuse.org
- Update to version 1.15.0:
  * chore(windows): fix automatic deploy for windows
  * chore(release): update qTox version to v1.15.0
  * chore(l10n): update translations from Weblate
  * chore(windows): automatically deploy for windows
  * chore(version): update toxcore version to v0.2.2
  * perf(ui): cache stylesheets to reduce memory usage
  * fix(settings): connect enable LAN discovery checkbox
  * fix(core): split messages on utf8 multibyte character boundary properly
  * feat(camera): add higher resolution camera options
  * refactor(avform): simplify and standardize sliders, use RMS for volume
  * fix(audio): apply gain to both audio channels
  * fix(audio): move audio timers to and start from audioThread
  * refactor(ui): consolidate new message settings under UI page
  * feat(ui): add setting for disabling new message notification popup
  * feat(ui): Add ability to disable LAN discovery
  * fix(profile): don't error if no new avatar is selected
  * fix(chatform): include pressed key(s) when changing focus
  * fix(settings): add missing enableTestSound to settings
  * fix(ui): remove placeholder update UI
  * fix(docs): include master key fingerprint instead of subkey fingerprint
  * refactor(call): Refactor toxcall and disconnect lambda on destruction
  * chore(windows): add architecture to installer's and zip's filenames
  * chore(windows): create a zip with qTox to be used in release publishing
  * chore(windows): use NSIS 3 and cache NSIS ShellExecAsUser plugin
  * chore(windows): bump VPX version to the latest (1.7.0)
  * chore(windows): bump Sodium version to the latest (1.0.16)
  * chore(windows): bump QREncode version to the latest (4.0.0)
  * chore(windows): bump FFmpeg 3.2 version to the latest (3.2.10)
  * chore(windows): bump SQLCipher version to the latest (3.4.2)
  * chore(windows): bump Qt 5.9 version to the latest (5.9.4)
  * chore(windows): bump OpenSSL version to the latest (1.0.2o)
  * feat(Weblate): create script to automatically merge Weblate changes
  * chore(windows): build installer on Travis
  * fix(history): don't save own messages when history is disabled
  * fix(docs): update dependencies for Debian
  * fix(login): Don't dereference null pointer
  * fix: remove build date and time from main.cpp
  * fix(import): don't use java-style iterator before first element
  * fix(offlinemsg): make faux offline messages purely event based
  * refactor: remove some unused includes
  * chore: put download URL for CircleCI artifacts in the build log
  * fix(IPC): Update profileName to update IPC ID after login screen
  * fix(chattextedit): ChatTextEdit bug fix for issue #5020 Corrected
  * docs(build): Add Fedora to the list of quick install
  * docs(build): Add Fedora simple install instructions
  * chore: remove unmaintained package build script
  * fix(name): Clear alias on name change so that name changes are visible
  * fix(build): Remove unused vars, add default case for switch
  * fix: don't use invalid reference after erasing element
  * fix(avform): Audio/Video settings tab #5011 issue bugfix
  * fix(widget): Fix double free crash on group leave
  * docs(readme): add GPG fingerprint of tox-user
- remove/drop patch fix_compiler_warnings.patch becaue no more need
- rebase spec to fix build error
* Mon Apr  2 2018 sleep_walker@opensuse.org
- improve summary and description of the package
* Thu Mar 22 2018 sleep_walker@opensuse.org
- move LICENSE to %%license section
- strip unneeded ldconfig
- disable filter_audio dependency - it is dead for more than 2 years
* Sun Mar 18 2018 jengelh@inai.de
- Trim filler wording from description.
* Sun Mar 18 2018 sleep_walker@opensuse.org
- use upstream patch and drop our -Wno-error= flags
* Sun Mar 18 2018 opensuse-packaging@opensuse.org
- Update to version 1.14.0:
  * chore(release): release v1.14.0
  * chore: update to c-toxcore 0.2.1
  * fix: Fix crash on manipulation with friend
  * fix(avform): Hotfix for crash on video device change on 'None'
  * fix(group): Show correct count of user on first creation
  * fix(friendwidget): Use queued connection to avoid removing 'this'
  * chore(l10n): update translations from Weblate
  * feat: Add the cmake option USE_CCACHE
  * refactor: update displayed user name from the friend model
  * refactor(friend): add an additional signal to Friend
  * fix(chatform): Broaden URL matching to include unicode
  * feat: update to the new c-toxcore 0.2.0 conferences api
  * fix(core): Adapt qtox to new conferences state change callback.
  * fix: Not quit on close if this setting is enabled
  * docs: add qttools5-dev to the dependencies list for Ubuntu
  * fix(widget): Fix status pic alignment
  * fix(chatlog): Match multi-character emoticons again
  * docs(fix): Write Macedonian in its national script
  * fix(build): move Appdata file installation to /usr/share/metainfo
  * fix(smiley): change license of classic smileys to CC BY-SA 4.0
  * refactor: add/delete checks in search code
  * refactor: rename hideButton to searchHideButton
  * fix: add search symbol ' in history
  * style: change code in searchInText
  * feat: add hot keys for search
  * feat: optimise search in history
  * feat: add search in text in group chats
  * feat: remove search button and add line in context menu
  * refactor: Move action handlers to slots
  * feat: edit load history for search
  * feat: add text search
  * feat: add form for search
  * feat: add a button to search
  * refactor: Remove ChatForm from Group
  * refactor: Remove using 'Group::getChatForm'
  * refactor: Save GroupChatForm in Widget
  * refactor: Remove chatForm from Friend
  * refactor: Move using loadHistory out of Friend
  * refactor: Remove using 'Friend::getChatForm'
  * refactor: Remove 'FriendWidget::setChatForm'
  * fix(chatlog): parse multi-length emoji properly
  * chore(cmake): Lookup toxcore's static dependencies
  * refactor(nexus): make loginscreen independent of nexus
  * refactor: cleanup notifications and core
  * chore: fix some compiler warnings
  * fix(core): Use new callback API for bitrate set
  * fix(core): Use new API for bitrate set
  * perf(widget): don't save on setExpanded if categorywidget is unchanged Fix #4932
  * docs(README): add GPG fingerprint of Anthony Bilinski as maintainer
  * refactor: Use qFuzzyCompare to compare float values
  * feat: Prefere new line as message break
  * fix: Use real channels number
  * refactor: Override only 'doOutput' and 'captureSamples' in OpenAL2
  * style: Fix style
  * fix: Allocate memory to input buffer
  * fix: Call doAudio on timer timeout
  * fix: [un]subscribe output in avform
  * chore: Don't dereference Tox_Options, use getters instead.
  * feat(groupchat): mark blocked users with different color
  * chore: Reorganization of the context menu for chat
  * chore: Update to immutable TES API and one-big-lib change.
  * fix(l10n): Correction of the translation into Russian
  * feat(UI): new status icons for message notifications
  * fix(build): add needed ffmpeg decoder to configuration
  * chore(i18n): update translation files for Weblate
  * feat(l10n): add Macedonian translation
  * feat(l10n): add Macedonian translation using Weblate
  * feat(l10n): update French translation from Weblate
  * feat(l10n): update Portuguese translation from Weblate
  * feat(l10n): update Portuguese translation from Weblate
  * fix(UI): prevent deadlocks on logout and profile delete
  * chore(CI): cache whole directory instead of globbing
  * chore(CI): silence CircleCI no tests warning
  * chore: update download links for Windows
  * chore: Elide text for CallConfirmWidget
  * chore(CI): copy artifacts from correct path
  * chore(CI): fix permissions on CircleCI
  * fix(windows): %%APPDATA -> %%APPDATA%% in template
  * chore(CI): use TravisCI scripts also for CircleCI
  * chore(CI): enable caching for CircleCI
  * chore(windows): untar files with default user/permissions
  * chore(CI): Add windows build with CircleCI
  * chore: disable broken autoupdater by default
  * fix: Correct display the call confirm window (CallConfirmWidget)
  * chore: update c-toxcore for all builds
  * revert: "fix(travis): switch back to older Ubuntu Image"
  * fix(travis): try working around Travis + gitstats issue
  * fix(l10n): Correction of the translation into Russian
* Wed Dec 27 2017 opensuse-packaging@opensuse.org
- Update to version 1.13.0:
  * refactor: Update AboutFriend with new interface
  * refactor: Add using IFriendSettings in AboutFriend model
  * refactor: Add IFriendSettings
  * fix(build): Add missing dependency for openSUSE
  * refactor: Use signal + slot to update view
  * refactor: Improve interface
  * fix(travis): switch back to older Ubuntu Image
  * fix(video): improve debug message
  * fix(video): choose first available resolution in preview automatically
  * fix(video): use float framerates also for V4L2
  * fix(video): allow not integer framerates
  * fix: elimination of warning '-Wreorder'
  * fix(cmake): fix platform extensions for windows
  * fix(chatwidget): fix send file button not working
  * fix(video): Fix square form of a video
  * fix(cpu): Reduce CPU usage by avatar render
  * fix(install): Fix gzip invalid usage
  * fix(cmake): add missing dependency
  * feat(avatar): Add outline hightlight on mouse hover
  * refactor: Make MaskablePixmapWidget allow to apply style
  * fix: Use epsilon to compare float
  * refactor: Remove code duplication from GroupWidget
  * refactor: Add pure virtual methods for main actions in chat
  * refactor: Move buttons style in ChatForm css
  * refactor(style): Move chatFormHeader to chatForm
  * refactor: Restruct code
  * refactor(chatform): Remove Nexus and Profile dependency from ChatForm
  * chore(build): Qt's website already does mirror load balancing
  * chore(build): bump Qt version to 5.9.3 for Windows
* Wed Dec 27 2017 sleep_walker@opensuse.org
- update to 1.13.0
  check CHANGELOG.md
- add CHANGELOG.md to documentation
- change to pkgconfig dependencies
- change from qmake to cmake
- run through spec-cleaner
- depend on c-toxcore instead of toxcore
* Sun Aug 16 2015 i@marguerite.su
- initial version 1.1+git20150722.74b7713:
  + OSX main menu bar
  + OSX usable menu bar on login screen
  + Update .gitattributes
  + core: TOX_ERR_NEW_LOAD_BAD_FORMAT is non-fatal.
  + German translation updates
  + Prevent crashed when default video format not found.
  + OSX: Remove dead code and make Widget own all their actions
  + Add sr.ht key
